@@ -4,6 +4,9 @@ mod tokio;
 #[cfg(feature = "sql-browser-async-std")]
 mod async_std;
 
+#[cfg(feature = "sql-browser-smol")]
+mod smol;
+
 use crate::client::Config;
 use async_trait::async_trait;
 
@@ -24,7 +27,11 @@ pub trait SqlBrowser {
         Self: Sized + Send + Sync;
 }
 
-#[cfg(any(feature = "sql-browser-async-std", feature = "sql-browser-tokio"))]
+#[cfg(any(
+    feature = "sql-browser-async-std",
+    feature = "sql-browser-tokio",
+    feature = "sql-browser-smol"
+))]
 fn get_port_from_sql_browser_reply(
     mut buf: Vec<u8>,
     len: usize,
